OC.L10N.register(
    "core",
    {
    "Please select a file." : "Veuillez sélectionner un fichier.",
    "File is too big" : "Le fichier est trop volumineux",
    "The selected file is not an image." : "Le fichier sélectionné n'est pas une image.",
    "The selected file cannot be read." : "Le fichier sélectionné ne peut pas être lu.",
    "The file was uploaded" : "Le fichier a été envoyé",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Le fichier envoyé dépasse la valeur upload_max_filesize spécifiée dans php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Le fichier envoyé dépasse la valeur MAX_FILE_SIZE spécifiée dans le formulaire HTML",
    "The file was only partially uploaded" : "Le fichier n'a été que partiellement envoyé",
    "No file was uploaded" : "Aucun fichier n'a été envoyé",
    "Missing a temporary folder" : "Absence de dossier temporaire",
    "Could not write file to disk" : "Impossible d'écrire le fichier sur le disque",
    "A PHP extension stopped the file upload" : "Une extension PHP a arrêté l'envoi du fichier",
    "Invalid file provided" : "Fichier non valide",
    "No image or file provided" : "Pas d'image ou fichier fourni",
    "Unknown filetype" : "Type de fichier inconnu",
    "An error occurred. Please contact your admin." : "Une erreur est survenue. Veuillez contacter votre administrateur.",
    "Invalid image" : "Image non valable",
    "No temporary profile picture available, try again" : "Aucune image de profil temporaire disponible, essayez à nouveau",
    "No crop data provided" : "Aucune donnée de recadrage fournie",
    "No valid crop data provided" : "Aucune donnée valide de recadrage fournie",
    "Crop is not square" : "Le recadrage n'est pas carré",
    "State token does not match" : "Les jetons de statut ne correspondent pas",
    "Invalid app password" : "Mot de passe d'application non valide",
    "Could not complete login" : "Impossible de terminer la connexion",
    "State token missing" : "Jeton d'état manquant",
    "Your login token is invalid or has expired" : "Votre jeton de connexion est invalide ou a expiré",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Cette version communautaire de Nextcloud n'est pas prise en charge et les notifications push sont limitées.",
    "Login" : "S'identifier",
    "Please try again" : "Veuillez réessayer",
    "Password reset is disabled" : "La réinitialisation du mot de passe est désactivée",
    "Could not reset password because the token is expired" : "Impossible de réinitialiser le mot de passe car le jeton d'authentification est expiré.",
    "Could not reset password because the token is invalid" : "Impossible de réinitialiser le mot de passe car le jeton d'authentification n'est pas valide.",
    "Password is too long. Maximum allowed length is 469 characters." : "Le mot de passe est trop long. La longueur maximale autorisée est de 469 caractères.",
    "%s password reset" : "Réinitialisation de votre mot de passe %s",
    "Password reset" : "Réinitialiser le mot de passe",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Cliquez sur le bouton suivant pour réinitialiser votre mot de passe. Si vous n'avez pas demandé cette réinitialisation de mot de passe, vous pouvez ignorer cet e-mail.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Cliquer sur le lien suivant pour réinitialiser votre mot de passe. Si vous n'avez pas demandé cette réinitialisation de mot de passe, alors ignorez ce e-mail.",
    "Reset your password" : "Réinitialiser votre mot de passe",
    "Nextcloud Server" : "Serveur Nextcloud",
    "Some of your link shares have been removed" : "Certains de vos liens partagés ont été supprimés.",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "En raison d'une faille de sécurité, nous avons supprimé certains de vos liens partagés. Consultez le lien ci-dessus pour plus d'information.",
    "The user limit of this instance is reached." : "Le nombre maximum d'utilisateurs a été atteint sur cette instance.",
    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Saisissez votre clé de licence dans l'application Support afin d'augmenter la limite d'utilisateurs. Cela vous donne également tous les avantages supplémentaires que Nextcloud Enterprise offre et est fortement recommandé pour l'exploitation dans les entreprises.",
    "Learn more ↗" : " En savoir plus ↗",
    "Preparing update" : "Préparation de la mise à jour",
    "[%d / %d]: %s" : "[%d / %d] : %s",
    "Repair step:" : "Étape de réparation :",
    "Repair info:" : "Informations de réparation :",
    "Repair warning:" : "Avertissement de réparation :",
    "Repair error:" : "Erreur de réparation :",
    "Please use the command line updater because updating via the browser is disabled in your config.php." : "Veuillez utiliser la mise à jour en ligne de commande, car la mise à jour via le navigateur est désactivée dans votre fichier config.php.",
    "Turned on maintenance mode" : "Mode de maintenance activé",
    "Turned off maintenance mode" : "Mode de maintenance désactivé",
    "Maintenance mode is kept active" : "Le mode de maintenance est laissé actif",
    "Updating database schema" : "Mise à jour du schéma de la base de données",
    "Updated database" : "Base de données mise à jour",
    "Update app \"%s\" from App Store" : "Mise à jour l'application \"%s\" depuis le magasin d'applications",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Vérification de la possibilité de mettre à jour le schéma de la base de données pour %s (cela peut prendre un certain temps selon la taille de la base de données)",
    "Updated \"%1$s\" to %2$s" : "Mise à jour de \"%1$s\" vers %2$s",
    "Set log level to debug" : "Réglage du niveau de journalisation à \"déboguage\"",
    "Reset log level" : "Réinitialisation du niveau de journalisation",
    "Starting code integrity check" : "Lancement de la vérification d'intégrité du code",
    "Finished code integrity check" : "Fin de la vérification d’intégrité du code",
    "%s (incompatible)" : "%s (incompatible)",
    "The following apps have been disabled: %s" : "Les applications suivantes ont été désactivées : %s",
    "Already up to date" : "Déjà à jour",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Votre serveur web n'est pas encore correctement configuré pour la synchronisation de fichiers parce que l'interface WebDAV semble ne pas fonctionner.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Votre serveur web nest pas configuré correctement pour résoudre \"{url}\".  Plus d'informations peuvent être trouvées sur notre <a target=\"_blank\" href=\"{docLink}\">documentation</a>.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Votre serveur web n'est pas proprement configuré pour résoudre \"{url}\". Ceci est probablement lié à une configuration du serveur web qui n'a pas été mise à jour pour délivrer directement ce dossier. Veuillez comparer votre configuration avec les règles ré-écrites dans \".htaccess\" pour Apache ou celles contenues dans la documentation de Nginx ici {linkstart}documentation page ↗{linkend}. Pour Nginx les lignes nécessitant une mise à jour sont typiquement celles débutant par \"location ~\".",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Votre serveur web n'est pas correctement configuré pour distribuer des fichiers .woff2. C'est une erreur fréquente de configuration Nginx. Pour Nextcloud 15, il est nécessaire de la régler pour les fichiers .woff2. Comparer votre configuration Nginx avec la configuration recommandée dans notre  {linkstart}documentation ↗{linkend}.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ne semble pas être configuré de manière à récupérer les valeurs des variables d’environnement. Le test de la commande getenv(\"PATH\") retourne seulement une réponse vide. ",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Veuillez consulter les notes de configuration pour PHP dans la {linkstart}documentation d'installation ↗{linkend} ainsi que la configuration de votre serveur, en particulier en cas d'utilisation de php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La configuration est en mode lecture seule. Ceci empêche la modification de certaines configurations via l'interface web. De plus, le fichier doit être passé manuellement en lecture-écriture avant chaque mise à jour.",
    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Vous n'avez pas encore défini ou vérifié la configuration de votre serveur de messagerie. Veuillez vous diriger vers les {mailSettingsStart}Paramètres de base{mailSettingsEnd} afin de les définir. Ensuite, utilisez le bouton \"Envoyer un e-mail\" sous le formulaire pour vérifier vos paramètres.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Votre base de données ne fonctionne pas avec le niveau d'isolation de transaction \"READ COMMITED\". Ceci peut causer des problèmes quand plusieurs actions sont exécutées en parallèle.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Le module PHP 'fileinfo' est manquant. Il est vivement recommandé de l'activer afin d'obtenir les meilleurs résultats de détection du type MIME.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Le verrouillage transactionnel de fichiers est désactivé, cela peut causer des conflits en cas d'accès concurrent. Configurez 'filelocking.enabled' dans config.php pour éviter ces problèmes. Consultez la {linkstart}documentation ↗{linkend} pour plus d'informations.",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Veillez à définir le paramètre \"overwrite.cli.url\" dans votre fichier config.php avec l'URL que vos utilisateurs utilisent principalement pour accéder à ce Nextcloud. Suggestion : \"{suggestedOverwriteCliURL}\". Sinon, il pourrait y avoir des problèmes avec la génération des URL via cron. (Il est toutefois possible que l'URL suggérée ne soit pas l'URL que vos utilisateurs utilisent principalement pour accéder à ce Nextcloud. Le mieux est de le vérifier deux fois dans tous les cas).",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Votre installation n’a pas de préfixe de région par défaut. C’est nécessaire pour valider les numéros de téléphone dans les paramètres du profil sans code pays. Pour autoriser les numéros sans code pays, veuillez ajouter \"default_phone_region\" avec le code {linkstart}ISO 3166-1 respectif {linkend} de la région dans votre fichier de configuration.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "La tâche cron n'a pu s'exécuter via CLI. Ces erreurs techniques sont apparues :",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "La dernière tâche de fond a été exécutée {relativeTime}. Quelque chose s'est mal passé. {linkstart}Vérifier le réglage des tâches de fond ↗{linkend}.",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Ceci est la version communautaire non prise en charge de Nextcloud. Compte tenu de la taille de cette instance, la performance, la fiabilité et la scalabilité ne peuvent être garanties. Les notifications push sont limitées pour éviter de surcharger notre service gratuit. Apprenez-en davantage sur les bénéfices de la version 'Nextcloud Entreprise' sur {linkstart}https://nextcloud.com/enterprise{linkend}.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Ce serveur ne peut se connecter à Internet : plusieurs points finaux ne peuvent être atteints. Cela signifie que certaines fonctionnalités, telles que le montage de stockages externes, les notifications de mises à jour ou l'installation d'applications tierces, ne fonctionneront pas. L'accès aux fichiers à distance, ainsi que l'envoi de notifications par e-mail peuvent aussi être indisponibles. Il est recommandé d'activer la connexion internet pour ce serveur si vous souhaitez disposer de l'ensemble des fonctionnalités offertes.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Pas de mémoire cache configurée. Pour améliorer les performances, merci de configurer un memcache, si disponible. Des informations sont disponibles dans la {linkstart}documentation ↗{linkend}.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Aucune source appropriée pour l'aléatoire n'a été trouvée par PHP, ce qui est fortement déconseillé pour des raisons de sécurité. Des informations complémentaires peuvent être trouvées dans la {linkstart}documentation ↗{linkend}.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Vous disposez actuellement de PHP {version}. Mettez à niveau votre version de PHP pour bénéficier des {linkstart}améliorations de performance et de correctifs de sécurité fournis par le groupe PHP ↗{linkend} dès que votre distribution les supporte.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "La configuration des entêtes du reverse proxy est incorrecte, ou vous accédez à Nextcloud depuis un proxy de confiance. Si ce n'est pas le cas, c'est un problème de sécurité, qui peut permettre à un attaquant d'usurper l'adresse IP affichée à Nextcloud. Plus d'information peuvent être trouvées dans la {linkstart}documentation ↗{linkend}.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached est configuré comme cache distribué, mais le mauvais module PHP \"memcache\" est installé. \\OC\\Memcache\\Memcached est le seul a supporter \"memcached\" et non \"memcache\". Se reporter au {linkstart}wiki memcached à propos des deux modules ↗{linkend}.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Certains fichiers n'ont pas passé la vérification d'intégrité. Plus d'informations sur la résolution de ce problème peuvent être trouvées dans la {linkstart1}documentation ↗{linkend}. ({linkstart2}Liste des fichiers invalides…{linkend} / {linkstart3}Rescanner…{linkend})",
    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "Le module PHP OPcache n'est pas correctement configuré. Veuillez regarder la {linkstart}documentation ↗{linkend} pour plus d'informations.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La fonction PHP \"set_time_limit\" n'est pas disponible. Cela pourrait entraîner l'arrêt des scripts à mi-exécution en bloquant votre installation. Nous vous recommandons vivement d'activer cette fonction.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Votre PHP ne prend pas en charge FreeType, provoquant la casse des images de profil et de l'interface des paramètres.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Index \"{indexName}\" manquant dans la table \"{tableName}\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "La base de données a quelques index manquants. L'ajout d'index dans de grandes tables peut prendre un certain temps. Elles ne sont donc pas ajoutées automatiquement. En exécutant \"occ db:add-missing-indices\", ces index manquants pourront être ajoutés manuellement pendant que l'instance continue de tourner. Une fois les index ajoutés, les requêtes sur ces tables sont généralement beaucoup plus rapides.",
    "Missing primary key on table \"{tableName}\"." : "Clé primaire manquante sur la table \"{tableName}\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Il manque des clés primaires dans la base de données. En raison du fait que l’ajout de clés primaires sur les grandes tables peut prendre un certain temps, elles n’ont pas été ajoutées automatiquement. En exécutant \"occ db:add-missing-primary-keys\", ces clés primaires manquantes peuvent être ajoutées manuellement pendant que l’instance continue de fonctionner.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Colonne optionnelle \"{columnName}\" manquante dans la table \"{tableName}\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Certaines colonnes facultatives sont manquantes dans la base de données. Étant donné qu'ajouter des colonnes sur des grandes tables peut prendre du temps, elles n'ont pas été ajoutées automatiquement lorsqu'elles sont facultatives. En exécutant \"occ db:add-missing-columns\" ces colonnes manquantes peuvent être ajoutées manuellement alors que l'instance continue de fonctionner. Une fois que les colonnes sont ajoutées, la performance ou l'utilisabilité de certaines fonctionnalités pourraient être améliorées.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Cette instance ne dispose pas de plusieurs modules PHP recommandés. Il est recommandé de les installer pour améliorer les performances, et la compatibilité.",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Le module PHP \"imagick\" n'est pas actif mais l'application Theming est activée. Pour que la génération du Favicon fonctionne correctement, ce module doit être installé et actif.",
    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "Les modules PHP \"gmp\" et/ou \"bcmath\" ne sont pas actifs. Si vous utilisez l'authentification sans mot de passe WebAuthn, ces modules sont requis.",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "Il semble que vous exécutiez une version 32 bits de PHP. Nextcloud nécessite 64 bits pour fonctionner correctement. Veuillez mettre votre système d'exploitation et PHP à niveau vers 64 bits ! Pour plus de détails, lisez {linkstart}la page de documentation ↗{linkend} à ce propos.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Le module php-imagick n’a aucun support SVG dans cette instance. Pour une meilleure compatibilité, il est recommandé de l’installer.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Certaines colonnes de la base de données n'ont pas été converties en 'big int'. Changer le type de colonne dans de grandes tables peut prendre beaucoup de temps, elles n'ont donc pas été converties automatiquement. En exécutant la commande 'occ db:convert-filecache-bigint', ces changements en suspens peuvent être déclenchés manuellement. Cette opération doit être exécutée pendant que l'instance est hors ligne. Pour plus d'information, consulter {linkstart}la page de documentation à ce propos ↗{linkend}.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite est actuellement utilisé comme système de gestion de base de données. Pour des installations plus volumineuses, nous vous recommandons de migrer vers un autre système de gestion de base de données.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "C'est particulièrement recommandé lorsque l'on utilise un client bureau pour la synchronisation des fichiers.",
    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "Pour migrer vers une autre base de données, utiliser la ligne de commande : 'occ db:convert-type', ou se reporter à la {linkstart}documentation ↗{linkend}.",
    "The PHP memory limit is below the recommended value of 512MB." : "La limite de mémoire PHP est inférieure à la valeur recommandée de 512 Mo.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Certains répertoires d'applications appartiennent à un utilisateur différent de celui du serveur web. Cela peut être le cas si les applications ont été installées manuellement. Vérifiez les permissions des répertoires d'applications suivants :",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL est utilisée comme base de données mais ne supporte pas les caractères codés sur 4 octets. Pour pouvoir manipuler les caractères sur 4 octets (comme les émoticônes) sans problème dans les noms de fichiers ou les commentaires par exemple, il est recommandé d'activer le support 4 octets dans MySQL. Pourr plus de détails, se reporter à la {linkstart}page de documentation à ce sujet ↗{linkend}.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Cette instance utilise un stockage primaire basé sur un objet de stockage issu de S3. \nLes fichiers téléversés sont temporairement stockés sur le serveur et il est donc recommandé de disposer d'un espace libre de 50 GB dans le répertoire temporaire de PHP. Vérifiez les journaux pour plus de détails sur les chemins concernés et l'espace disponible. Pour améliorer la situation, vous pouvez augmenter l'espace disponible dans le dossier temporaire actuel ou changer l'emplacement du dossier temporaire en indiquant un nouveau chemin dans php.ini.",
    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "Le dossier temporaire de cette instance pointe vers un dossier inexistant ou non modifiable.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Vous accédez à votre instance via une connexion sécurisée, pourtant celle-ci génère des URLs non sécurisées. Cela signifie probablement que vous êtes derrière un reverse-proxy et que les variables de réécriture ne sont pas paramétrées correctement. Se reporter à la {linkstart}page de documentation à ce sujet ↗{linkend}.",
    "Error occurred while checking server setup" : "Une erreur s'est produite lors de la vérification de la configuration du serveur",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Pour plus d’information, voir la {linkstart}documentation ↗{linkend}.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Votre dossier de données et vos fichiers sont probablement accessibles depuis internet. Le fichier .htaccess ne fonctionne pas. Nous vous recommandons vivement de configurer votre serveur web de façon à ce que ce dossier de données ne soit plus accessible, ou de le déplacer hors de la racine du serveur web.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "L'en-tête HTTP \"{header}\" n'est pas configurée pour être égale à \"{expected}\". Ceci constitue un risque potentiel relatif à la sécurité et à la vie privée étant donné qu'il est recommandé d'ajuster ce paramètre.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "L'en-tête HTTP \"{header}\" n'est pas configurée pour être égale à \"{expected}\". Certaines fonctionnalités peuvent ne pas fonctionner correctement étant donné qu'il est recommandé d'ajuster ce paramètre.",
    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "L'entête HTTP \"{header}\" ne contient pas \"{expected}\". Cela constitue potentiellement un risque relatif à la de sécurité ou à la confidentialité, aussi, il est recommandé d'ajuster ce paramètre en conséquence. ",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "L'en-tête HTTP \"{header}\" n'est pas défini sur \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" ou \"{val5}\". Cela peut entraîner une fuite d'informations. Se reporter aux  {linkstart}recommandations du W3C ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "L'en-tête HTTP \"Strict-Transport-Security\" n'est pas configuré à au moins \"{seconds}\" secondes. Pour une sécurité renforcée, il est recommandé d'activer HSTS comme indiqué dans les {linkstart}éléments de sécurité ↗{linkend}.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Accès non sécurisé au site via HTTP. Il est fortement conseillé de configurer votre serveur pour exiger HTTPS à la place, comme décrit dans les {linkstart}conseils de sécurité ↗{linkend}.",
    "unknown text" : "texte inconnu",
    "Hello world!" : "Hello world!",
    "sunny" : "ensoleillé",
    "Hello {name}, the weather is {weather}" : "Bonjour {name}, le temps est {weather}",
    "Hello {name}" : "Bonjour {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Voici les résultats de votre recherche<script>alert(1)</script></strong>",
    "new" : "nouveau ",
    "_download %n file_::_download %n files_" : ["télécharger %n fichier","télécharger %n fichiers","télécharger %n fichiers"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "La mise à jour est en cours, quitter la page peut interrompre le processus dans de nombreux environnements.",
    "Update to {version}" : "Mettre à jour vers {version}",
    "An error occurred." : "Une erreur est survenue.",
    "Please reload the page." : "Veuillez recharger la page.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La mise à jour a échoué. Pour plus d'informations <a href=\"{url}\">consultez notre publication sur le forum</a> à propos de ce problème.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La mise à jour a échoué. Veuillez reporter le problème à la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">communauté Nextcloud</a>.",
    "Continue to {productName}" : "Continuer vers {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["La mise à jour est terminée. Vous allez être redirigé vers {productName} dans %n secondes.","La mise à jour est terminée. Vous allez être redirigé vers {productName} dans %n secondes.","La mise à jour est terminée. Vous allez être redirigé vers {productName} dans %n secondes."],
    "More apps" : "Plus d'applications",
    "Currently open" : "Actuellement ouvert",
    "_{count} notification_::_{count} notifications_" : ["{count} notification","{count} notifications","{count} notifications"],
    "Log in" : "Se connecter",
    "Logging in …" : "Connexion…",
    "Server side authentication failed!" : "L'authentification sur le serveur a échoué !",
    "Please contact your administrator." : "Veuillez contacter votre administrateur.",
    "An internal error occurred." : "Une erreur interne est survenue.",
    "Please try again or contact your administrator." : "Veuillez réessayer ou contactez votre administrateur.",
    "Account name or email" : "Nom d'utilisateur ou adresse e-mail",
    "Password" : "Mot de passe",
    "Log in to {productName}" : "Se connecter à {productName}",
    "Wrong username or password." : "Utilisateur ou mot de passe incorrect.",
    "User disabled" : "Utilisateur désactivé",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Nous avons détecté plusieurs tentatives de connexion invalides depuis votre adresse IP. C'est pourquoi votre prochaine connexion sera retardée de 30 secondes.",
    "Username or email" : "Nom d'utilisateur ou e-mail",
    "Your account is not setup for passwordless login." : "Votre compte n'est pas paramétré pour une authentification sans mot de passe.",
    "Browser not supported" : "Navigateur non compatible",
    "Passwordless authentication is not supported in your browser." : "L'authentification sans mot de passe n'est pas supportée par votre navigateur.",
    "Your connection is not secure" : "Votre connexion n'est pas sécurisée",
    "Passwordless authentication is only available over a secure connection." : "L'authentification sans mot de passe n'est possible qu'au travers d'une connexion sécurisée.",
    "Reset password" : "Réinitialiser le mot de passe",
    "Couldn't send reset email. Please contact your administrator." : "Impossible d'envoyer l'e-mail de réinitialisation. Veuillez contacter votre administrateur.",
    "Password cannot be changed. Please contact your administrator." : "Le mot de passe ne pas être modifié. Veuillez contacter votre administrateur.",
    "Back to login" : "Retour à la page de connexion",
    "New password" : "Nouveau mot de passe",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Vos fichiers sont chiffrés. Il n'y aura aucun moyen de récupérer vos données après la réinitialisation de votre mot de passe. Si vous n'êtes pas sûr de ce que vous faîtes, veuillez contacter votre administrateur avant de continuer. Voulez-vous vraiment continuer ?",
    "I know what I'm doing" : "Je sais ce que je fais",
    "Resetting password" : "Réinitialisation du mot de passe",
    "Recommended apps" : "Applis recommandées",
    "Loading apps …" : "Chargement des applis…",
    "Could not fetch list of apps from the App Store." : "Impossible de récupérer la liste des applications depuis le magasin d'applications",
    "Installing apps …" : "Installation des applis en cours...",
    "App download or installation failed" : "Échec lors du téléchargement ou de l'installation de l'appli",
    "Cannot install this app because it is not compatible" : "Impossible d'installer cette app parce qu'elle n'est pas compatible",
    "Cannot install this app" : "Impossible d'installer cette app",
    "Skip" : "Ignorer",
    "Install recommended apps" : "Installer les applications recommandées",
    "Schedule work & meetings, synced with all your devices." : "Planifiez votre travail et des réunions, synchronisées avec tous vos appareils.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Gardez les contacts de vos collègues et amis au même endroit sans divulguer leurs informations personnelles.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Application de messagerie électronique simple et bien intégrée avec Fichiers, Contacts et Calendrier.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Discussions, appels vidéo, partage d'écran, réunions en ligne et conférences web – depuis votre navigateur et les applications mobiles.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documents, feuilles de calculs ou présentations créées sur Collabora Online.",
    "Distraction free note taking app." : "Application de prise de notes sans distraction.",
    "Search contacts" : "Rechercher des contacts",
    "Forgot password?" : "Mot de passe oublié ?",
    "Log in with a device" : "Se connecter avec un périphérique",
    "Back" : "Retour",
    "Login form is disabled." : "Le formulaire de connexion est désactivé.",
    "Edit Profile" : "Modifier le profil",
    "The headline and about sections will show up here" : "Le titre et la section \"À propos\" apparaîtront ici",
    "You have not added any info yet" : "Vous n'avez pas ajouté d'informations pour le moment",
    "{user} has not added any info yet" : "{user} n'a pas ajouté d'informations pour le moment",
    "Error opening the user status modal, try hard refreshing the page" : "Erreur lors de l'ouverture du modal du statut de l'utilisateur, essayez d'actualiser la page",
    "Search starts once you start typing and results may be reached with the arrow keys" : "La recherche démarre dès que vous commencez à taper et les résultats peuvent être atteints avec les flèches du clavier",
    "Reset search" : "Réinitialiser la recherche",
    "Start search" : "Démarrer la recherche",
    "Search for {name} only" : "Rechercher pour {name} uniquement",
    "Start typing to search" : "Tapez pour lancer la recherche",
    "Loading more results …" : "Chargement de plus de résultats …",
    "Load more results" : "Charger plus de résultats",
    "Search" : "Rechercher",
    "No results for {query}" : "Aucun résultat pour {query}",
    "An error occurred while searching for {type}" : "Une erreur s'est produite lors de la recherche de {type}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Veuillez saisir au moins {minSearchLength} caractère pour lancer la recherche","Veuillez saisir au moins {minSearchLength} caractères pour lancer la recherche","Veuillez saisir au moins {minSearchLength} caractères pour lancer la recherche"],
    "This browser is not supported" : "Ce navigateur n'est pas supporté",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Votre navigateur n'est pas pris en charge. Veuillez passer à une version plus récente ou à un navigateur supporté.",
    "Continue with this unsupported browser" : "Continuer avec ce navigateur non pris en charge",
    "Supported versions" : "Versions supportées",
    "{name} version {version} and above" : "{nom} version {version} et supérieure",
    "Open settings menu" : "Ouvrir le menu des paramètres",
    "Settings menu" : "Menu des paramètres",
    "Search {types} …" : "Rechercher {types}…",
    "Settings" : "Paramètres",
    "Avatar of {fullName}" : "Avatar de {fullName}",
    "Could not load your contacts" : "Impossible de charger vos contacts",
    "Search contacts …" : "Rechercher un contact...",
    "No contacts found" : "Aucun contact trouvé",
    "Show all contacts …" : "Afficher tous les contacts...",
    "Install the Contacts app" : "Installer l'appli Contacts",
    "Loading your contacts …" : "Chargement de vos contacts...",
    "Looking for {term} …" : "Recherche de {term} ...",
    "No" : "Non",
    "Yes" : "Oui",
    "No files in here" : "Aucun fichier",
    "New folder" : "Nouveau dossier",
    "No more subfolders in here" : "Plus aucun sous-dossier ici",
    "Name" : "Nom",
    "Size" : "Taille",
    "Modified" : "Modifié",
    "\"{name}\" is an invalid file name." : "\"{name}\" n'est pas un nom de fichier valide.",
    "File name cannot be empty." : "Le nom de fichier ne peut pas être vide.",
    "\"/\" is not allowed inside a file name." : "\"/\" n'est pas autorisé dans un nom de fichier.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" n'est pas un type de fichier autorisé",
    "{newName} already exists" : "{newName} existe déjà",
    "Choose" : "Choisir",
    "Copy" : "Copier",
    "Move" : "Déplacer",
    "Error loading file picker template: {error}" : "Erreur lors du chargement du modèle du sélecteur de fichiers : {error}",
    "OK" : "OK",
    "Error loading message template: {error}" : "Erreur lors du chargement du modèle de message : {error}",
    "read-only" : "Lecture seule",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} fichier en conflit","{count} fichiers en conflit","{count} fichiers en conflit"],
    "One file conflict" : "Un conflit de fichier",
    "New Files" : "Nouveaux fichiers",
    "Already existing files" : "Fichiers déjà existants",
    "Which files do you want to keep?" : "Quels fichiers souhaitez-vous conserver ?",
    "If you select both versions, the copied file will have a number added to its name." : "Si vous sélectionnez les deux versions, un nombre sera ajouté au nom du fichier copié.",
    "Cancel" : "Annuler",
    "Continue" : "Continuer",
    "(all selected)" : "(tous sélectionnés)",
    "({count} selected)" : "({count} sélectionné(s))",
    "Error loading file exists template" : "Erreur lors du chargement du modèle de fichier existant",
    "Show list view" : "Activer l'affichage liste",
    "Show grid view" : "Activer l'affichage mosaïque",
    "Pending" : "En attente",
    "Home" : "Personnel",
    "Copy to {folder}" : "Copier vers {folder}",
    "Move to {folder}" : "Déplacer vers {folder}",
    "Saving …" : "Enregistrement...",
    "Authentication required" : "Authentification requise",
    "This action requires you to confirm your password" : "Cette action nécessite que vous confirmiez votre mot de passe",
    "Confirm" : "Confirmer",
    "Failed to authenticate, try again" : "Échec d'authentification, essayez à nouveau",
    "seconds ago" : "Il y a quelques secondes",
    "Connection to server lost" : "La connexion au serveur a été perdue",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problème de chargement de la page, actualisation dans %n seconde","Problème de chargement de la page, actualisation dans %n secondes","Problème de chargement de la page, actualisation dans %n secondes"],
    "Add to a project" : "Ajouter à un projet",
    "Show details" : "Afficher les détails",
    "Hide details" : "Masquer les détails",
    "Rename project" : "Renommer le projet",
    "Failed to rename the project" : "Impossible de renommer le projet",
    "Failed to create a project" : "Impossible de créer un projet",
    "Failed to add the item to the project" : "Impossible d'ajouter l'élément au projet",
    "Connect items to a project to make them easier to find" : "Reliez des éléments à un projet pour les retrouver plus facilement",
    "Type to search for existing projects" : "Saisissez du texte pour rechercher un projet existant",
    "New in" : "Nouveau dans",
    "View changelog" : "Voir le journal des modifications",
    "Very weak password" : "Mot de passe très faible",
    "Weak password" : "Mot de passe faible",
    "So-so password" : "Mot de passe tout juste acceptable",
    "Good password" : "Mot de passe de sécurité suffisante",
    "Strong password" : "Mot de passe fort",
    "No action available" : "Aucune action disponible",
    "Error fetching contact actions" : "Erreur lors de la recherche d'actions de contact",
    "Close \"{dialogTitle}\" dialog" : "Fermer la boîte de dialogue \"{dialogTitle}\"",
    "Non-existing tag #{tag}" : "Étiquette #{tag} inexistante",
    "Restricted" : "Restreint",
    "Invisible" : "Invisible",
    "Delete" : "Supprimer",
    "Rename" : "Renommer",
    "Collaborative tags" : "Étiquettes collaboratives ",
    "No tags found" : "Aucune étiquette n'a été trouvée",
    "Personal" : "Personnel",
    "Users" : "Utilisateurs",
    "Apps" : "Applications",
    "Admin" : "Administration",
    "Help" : "Aide",
    "Access forbidden" : "Accès non autorisé",
    "Profile not found" : "Profile introuvable",
    "The profile does not exist." : "Le profile n'existe pas.",
    "Back to %s" : "Retour à %s",
    "Page not found" : "Page non trouvée",
    "The page could not be found on the server." : "La page n'a pas pu être trouvée sur le serveur.",
    "Too many requests" : "Trop de requêtes",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Il y a trop de requêtes depuis votre réseau. Réessayez plus tard ou contactez votre administrateur s'il s'agit d'une erreur.",
    "Error" : "Erreur",
    "Previous" : "Précédent",
    "Internal Server Error" : "Erreur interne du serveur",
    "The server was unable to complete your request." : "Le serveur est incapable d'exécuter votre requête.",
    "If this happens again, please send the technical details below to the server administrator." : "Si cela se reproduit, veuillez envoyer les détails techniques ci-dessous à l'administrateur du serveur.",
    "More details can be found in the server log." : "Le fichier journal du serveur peut fournir plus de renseignements.",
    "Technical details" : "Renseignements techniques",
    "Remote Address: %s" : "Adresse distante : %s",
    "Request ID: %s" : "ID de la demande : %s",
    "Type: %s" : "Type : %s",
    "Code: %s" : "Code : %s",
    "Message: %s" : "Message : %s",
    "File: %s" : "Fichier : %s",
    "Line: %s" : "Ligne : %s",
    "Trace" : "Trace",
    "Security warning" : "Avertissement de sécurité",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Votre répertoire de données est certainement accessible depuis internet car le fichier .htaccess ne fonctionne pas.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pour les informations de configuration de votre serveur, veuillez lire la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
    "Create an <strong>admin account</strong>" : "Créer un <strong>compte administrateur</strong>",
    "Username" : "Nom d'utilisateur",
    "Show password" : "Afficher le mot de passe",
    "Toggle password visibility" : "Activer/Désactiver la visibilité du mot de passe",
    "Storage & database" : "Stockage & base de données",
    "Data folder" : "Répertoire des données",
    "Configure the database" : "Configurer la base de données",
    "Only %s is available." : "Seul(e) %s est disponible.",
    "Install and activate additional PHP modules to choose other database types." : "Installez et activez les modules PHP additionnels adéquats pour choisir d'autres types de base de données.",
    "For more details check out the documentation." : "Consultez la documentation pour plus de détails.",
    "Database user" : "Utilisateur de la base de données",
    "Database password" : "Mot de passe de la base de données",
    "Database name" : "Nom de la base de données",
    "Database tablespace" : "Espace de stockage de la base de données",
    "Database host" : "Hôte de la base de données",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Veuillez spécifier le numéro du port avec le nom de l'hôte (ex: localhost:5432).",
    "Performance warning" : "Avertissement à propos des performances",
    "You chose SQLite as database." : "Vous avez choisi SQLite comme base de données. ",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite ne devrait être utilisée que pour des instances minimales ou de développement. Pour une instance de production, nous recommandons une infrastructure de base de données différente. ",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si vous utilisez des clients de synchronisation de fichiers, l'utilisation de SQLite est fortement découragée. ",
    "Install" : "Installer",
    "Installing …" : "Installation...",
    "Need help?" : "Besoin d'aide ?",
    "See the documentation" : "Lire la documentation",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "On dirait que vous essayez de réinstaller votre Nextcloud. Toutefois, le fichier CAN_INSTALL est absent de votre répertoire de configuration. Veuillez créer le fichier CAN_INSTALL dans votre dossier de configuration pour continuer.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Impossible de supprimer CAN_INSTALL du dossier de configuration. Veuillez supprimer ce fichier manuellement.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Cette application requiert JavaScript pour fonctionner correctement. Veuillez {linkstart}activer JavaScript{linkend} et recharger la page.",
    "Skip to main content" : "Passer au contenu principal",
    "Skip to navigation of app" : "Passer à la navigation d'application",
    "Get your own free account" : "Obtenez votre compte personnel gratuit",
    "Go to %s" : "Aller à %s",
    "Confirm your password" : "Confirmer votre mot de passe",
    "Connect to your account" : "Connectez vous à votre compte",
    "Please log in before granting %1$s access to your %2$s account." : "Veuillez vous connecter avant d'autoriser %1$s à accéder à votre compte %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si vous n'essayez pas d'ajouter un nouveau périphérique ou une nouvelle application, quelqu'un fait une tentative d'accès à vos données. Dans ce cas, ne continuez pas et contactez votre administrateur système.",
    "App token" : "Jeton d'application",
    "Grant access" : "Autoriser l'accès",
    "Alternative log in using app token" : "Authentification alternative en utilisant un jeton d'application",
    "Account access" : "Accès au compte",
    "Currently logged in as %1$s (%2$s)." : "Connecté en tant que %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Vous êtes sur le point d'accorder à \"%1$s\" l'accès à votre compte \"%2$s\".",
    "Account connected" : "Compte connecté",
    "Your client should now be connected!" : "Votre client devrait maintenant être connecté !",
    "You can close this window." : "Vous pouvez fermer cette fenêtre.",
    "This share is password-protected" : "Ce partage est protégé par mot de passe",
    "The password is wrong or expired. Please try again or request a new one." : "Le mot de passe est incorrect ou expiré. Ré-essayez ou demandez-en un nouveau.",
    "Please type in your email address to request a temporary password" : "Veuillez saisir votre adresse e-mail pour recevoir un mot de passe temporaire",
    "Email address" : "Adresse e-mail",
    "Password sent!" : "Mot de passe envoyé !",
    "You are not authorized to request a password for this share" : "Vous n'êtes pas autorisé à demander un mot de passe pour ce partage",
    "Two-factor authentication" : "Second facteur d'authentification",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "La sécurité renforcée est activée pour votre compte. Choisissez un second facteur pour l'authentification :",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Impossible de charger au moins l'une de vos méthodes activées d'authentification à deux facteurs . Veuillez contacter votre administrateur.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "L'authentification en deux étapes a été imposée mais n'est pas configurée sur votre compte. Contactez votre administrateur pour avoir de l'aide.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "L'authentification à deux facteurs est appliquée mais n'a pas été configurée sur votre compte. Veuillez continuer à configurer l'authentification à deux facteurs.",
    "Set up two-factor authentication" : "Paramétrer l'authentification à double facteur",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "L'authentification en deux étapes a été imposée mais n'est pas configurée sur votre compte. Utilisez un de vos codes de secours pour vous connecter ou contactez votre administrateur pour avoir de l'aide.",
    "Use backup code" : "Utiliser un code de récupération",
    "Cancel login" : "Annuler la connexion",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "La sécurité renforcée est appliquée à votre compte. Choisissez le fournisseur à configurer :",
    "Error while validating your second factor" : "Erreur lors de la validation de votre second facteur",
    "Access through untrusted domain" : "Accès à partir d'un domaine non approuvé",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Veuillez contacter votre administrateur. Si vous êtes un administrateur, éditez la variable \"trusted_domains\" dans le fichier config/config.php comme l'exemple dans le fichier config/config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Vous trouverez d'autres informations sur la configuration dans la %1$sdocumentation %2$s.",
    "App update required" : "Mise à jour de l'application nécessaire",
    "%1$s will be updated to version %2$s" : "%1$s sera mis à jour vers la version %2$s",
    "The following apps will be updated:" : "Les applications suivantes vont être mises à jour :",
    "These incompatible apps will be disabled:" : "Ces applications incompatibles ont été désactivées :",
    "The theme %s has been disabled." : "Le thème %s a été désactivé.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Veuillez vous assurer qu'une copie de sauvegarde de la base de données, du dossier de configuration (config) et du dossier de données (data) a été réalisée avant de commencer.",
    "Start update" : "Démarrer la mise à jour",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Afin d'éviter les délais d'expiration avec les installations de volume conséquent, vous pouvez exécuter la commande suivante depuis le répertoire d'installation :",
    "Detailed logs" : "Journaux détaillés",
    "Update needed" : "Mise à jour nécessaire",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Veuillez utiliser la mise à jour en ligne de commande car votre instance est volumineuse avec plus de 50 utilisateurs.",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Veuillez utiliser la mise à jour en ligne de commande, la mise à jour automatique est désactivée dans config.php.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pour obtenir de l'aide, lisez la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Je sais que si je continue à faire la mise à jour via le navigateur web, il existe le risque que la requête se heurte à un délai d'expiration et peut causer une perte de données, mais j'ai une copie de sauvegarde et je sais comment restaurer mon instance en cas d'échec.",
    "Upgrade via web on my own risk" : "Mettre à jour via le navigateur web à mes propres risques",
    "Maintenance mode" : "Mode maintenance",
    "This %s instance is currently in maintenance mode, which may take a while." : "Cette instance de %s est en cours de maintenance, cela peut prendre du temps.",
    "This page will refresh itself when the instance is available again." : "Cette page se rafraîchira d'elle-même lorsque le serveur sera de nouveau disponible.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Veuillez contacter votre administrateur système si ce message persiste ou apparaît de façon inattendue.",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Cette version communautaire de Nextcloud n'est pas prise en charge et les notifications push ne sont pas disponibles.",
    "[%d / %d]: Checking table %s" : "[%d / %d] : Vérification de la table %s",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Il s'agit de la version communautaire non prise en charge de Nextcloud. Compte tenu de la taille de cette instance, les performances, la fiabilité et l'extensibilité ne peuvent être garanties. Les notifications push ont été désactivées pour éviter de surcharger notre service gratuit. Apprenez-en plus sur les avantages de Nextcloud Enterprise sur nextcloud.com/enterprise.",
    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 est la dernière version prenant en charge PHP 7.3. Nextcloud 24 nécessite au moins PHP 7.4.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "L'en-tête HTTP \"{header}\" ne contient pas \"{expected}\". Ceci est un risque potentiel pour la sécurité ou la vie privée, et il est recommandé d'ajuster ce paramètre en conséquence.",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Un message de réinitialisation de votre mot de passe a été envoyé à l'adresse e-mail renseignée pour ce compte. Si vous ne le recevez pas, veuillez vérifier dans votre dossier spam ou demander de l'aide à l'administrateur de cette instance.",
    "If it is not there ask your local administrator." : "Si ce n'est pas le cas, veuillez contacter votre administrateur.",
    "Collaboratively edit office documents." : "Modifier des documents de manière collaborative.",
    "Local document editing back-end used by the Collabora Online app." : "Moteur d'édition de document local utilisé par l'application Collabora Online.",
    "restricted" : "Restreint",
    "invisible" : "invisible",
    "File not found" : "Fichier non trouvé",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Le document n'a pas pu être trouvé sur le serveur. Peut-être que le partage a été supprimé ou a expiré ?",
    "More" : "Plus",
    "More apps menu" : "Menu des autres applications",
    "Contacts" : "Contacts",
    "Contacts menu" : "Menu des contacts",
    "Setup two-factor authentication" : "Paramétrer l'authentification à double facteur",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Il semble que vous utilisez une version 32-bits de PHP. Nextcloud nécessite une version 64-bits pour bien fonctionner. Merci de mettre à niveau votre système d'exploitation et PHP en 64-bits. Pour plus de détails consultez {linkstart}the documentation page about this ↗{linkend}.",
    "Press enter to start searching" : "Appuyez sur Entrée pour démarrer la recherche",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Veuillez utiliser la mise à jour en ligne de commande, car la mise à jour via le navigateur est désactivée dans votre fichier config.php."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
